==> pmml-model-gwt-1.4.10.jar: org/dmg/pmml/text/TextModelSimiliarity.java <==

package org.dmg.pmml.text;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.StringValue;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Property;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "TextModelSimiliarity", namespace = "http://www.dmg.org/PMML-4_3")
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "similarityType",
    "extensions"
})
public class TextModelSimiliarity
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<TextModelSimiliarity>
{

    @XmlAttribute(name = "similarityType")
    @JsonProperty("similarityType")
    private TextModelSimiliarity.SimilarityType similarityType;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67305487L;

    public TextModelSimiliarity.SimilarityType getSimilarityType() {
        return similarityType;
    }

    public TextModelSimiliarity setSimilarityType(
        @Property("similarityType")
        TextModelSimiliarity.SimilarityType similarityType) {
        this.similarityType = similarityType;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public TextModelSimiliarity addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

    @XmlType(name = "")
    @XmlEnum
    public enum SimilarityType
        implements StringValue<TextModelSimiliarity.SimilarityType>
    {

        @XmlEnumValue("euclidean")
        @JsonProperty("euclidean")
        EUCLIDEAN("euclidean"),
        @XmlEnumValue("cosine")
        @JsonProperty("cosine")
        COSINE("cosine");
        private final String value;

        SimilarityType(String v) {
            value = v;
        }

        @Override
        public String value() {
            return value;
        }

        public static TextModelSimiliarity.SimilarityType fromValue(String v) {
            for (TextModelSimiliarity.SimilarityType c: TextModelSimiliarity.SimilarityType.values()) {
                if (c.value.equals(v)) {
                    return c;
                }
            }
            throw new IllegalArgumentException(v);
        }

        @Override
        public String toString() {
            return value();
        }

    }

}

==> pmml-model-gwt-1.5.5.jar: org/dmg/pmml/text/TextModelSimiliarity.java <==

package org.dmg.pmml.text;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.StringValue;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Property;

@XmlRootElement(name = "TextModelSimiliarity", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions"
})
@JsonRootName("TextModelSimiliarity")
@JsonPropertyOrder({
    "similarityType",
    "extensions"
})
public class TextModelSimiliarity
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<TextModelSimiliarity>
{

    @XmlAttribute(name = "similarityType")
    @JsonProperty("similarityType")
    private TextModelSimiliarity.SimilarityType similarityType;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67371265L;

    public TextModelSimiliarity.SimilarityType getSimilarityType() {
        return similarityType;
    }

    public TextModelSimiliarity setSimilarityType(
        @Property("similarityType")
        TextModelSimiliarity.SimilarityType similarityType) {
        this.similarityType = similarityType;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public TextModelSimiliarity addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

    @XmlType(name = "")
    @XmlEnum
    public enum SimilarityType
        implements StringValue<TextModelSimiliarity.SimilarityType>
    {

        @XmlEnumValue("euclidean")
        @JsonProperty("euclidean")
        EUCLIDEAN("euclidean"),
        @XmlEnumValue("cosine")
        @JsonProperty("cosine")
        COSINE("cosine");
        private final String value;

        SimilarityType(String v) {
            value = v;
        }

        @Override
        public String value() {
            return value;
        }

        public static TextModelSimiliarity.SimilarityType fromValue(String v) {
            for (TextModelSimiliarity.SimilarityType c: TextModelSimiliarity.SimilarityType.values()) {
                if (c.value.equals(v)) {
                    return c;
                }
            }
            throw new IllegalArgumentException(v);
        }

        @Override
        public String toString() {
            return value();
        }

    }

}
